import ipynbname
import pkg_resources
import os

from ml_sdk.ml.model.notebook import WatchmenNotebook


def get_notebook(storage_type:str,storage_location:str = None):
    note_name = ipynbname.name()
    path = ipynbname.path()
    if storage_location is not None:
        notebook = WatchmenNotebook(name=note_name, storageLocation=storage_location, storageType=storage_type)
    else:
        notebook = WatchmenNotebook(name=note_name, storageLocation=str(path), storageType=storage_type)

    return get_dependencies(notebook)


def get_dependencies(notebook: WatchmenNotebook):
    for m in pkg_resources.working_set:
        notebook.dependencies[m.project_name] = m.version
    return notebook


def get_environment():
    environments = {}
    # environments = os.environ.values()
    for item, value in os.environ.items():
        environments[item] = value

    return environments





import os

from ml_sdk.ml.sdk.watchmen.sdk import load_dataset_by_name, push_notebook_to_watchmen
from ml_sdk.ml.unitls import get_notebook, get_environment


class WatchmenClient(object):
    def __init__(self, token):
        if token:
            self.token = token
        else:
            self.token = os.environ.get('TOKEN')

    def load_dataset(self, name):
        return load_dataset_by_name(self.token, name)

    def register_notebook(self, storage_type="file"):
        notebook = get_notebook(storage_type)
        notebook.environment = get_environment()
        response = push_notebook_to_watchmen(notebook,self.token)
        if response.status_code == 200:
            print("push notebook successfully")
        return notebook

    def save_topic_dataset(self, topic_name: str, dataset):
        pass





    def register_model(self):
        pass

#
# client  = WatchmenClient(token="0Z6ag50cdIPamBIgf8KfoQ")
# df = client.load_dataset("DEMO")
# print(df)



from typing import Optional

from pydantic import BaseModel


class WatchmenNotebook(BaseModel):
    name:str = None
    storageType:str = None
    storageLocation:str = None
    environment:dict = {}
    dependencies:dict = {}







import json
import pandas as pd
import requests

from ml_sdk.ml.model.notebook import WatchmenNotebook

local_env_url = "http://localhost:8000"


def build_headers(token):
    headers = {"Content-Type": "application/json"}
    headers["authorization"] = "pat " + token
    return headers


def build_indicators(columns):
    indicators = []
    for column in columns:
        indicators.append({"columnId": column["columnId"], "name": column["alias"]})
    return indicators


def load_dataset_by_name(token, name):
    response = requests.get(local_env_url + "/subject/name", params={"name": name}, headers=build_headers(token))
    subject = response.json()
    ## TODO  columns type
    indicators_list = build_indicators(subject["dataset"]["columns"])
    criteria = {
        "subjectId": subject["subjectId"],
        "indicators": indicators_list
    }
    response = requests.post(local_env_url + "/subject/data/criteria", data=json.dumps(criteria),
                             headers=build_headers(token))
    dataset = response.json()["data"]
    return pd.DataFrame(dataset, columns=list(map(lambda x: x["name"], indicators_list)))


def push_notebook_to_watchmen(notebook:WatchmenNotebook,token):
    response = requests.post(local_env_url + "/notebook", data=json.dumps(notebook),
                             headers=build_headers(token))


# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['ml_sdk',
 'ml_sdk.ml',
 'ml_sdk.ml.model',
 'ml_sdk.ml.sdk',
 'ml_sdk.ml.sdk.watchmen']

package_data = \
{'': ['*']}

install_requires = \
['ipynbname>=2021.3.2,<2022.0.0',
 'pandas>=1.4.2,<2.0.0',
 'pydantic>=1.9.1,<2.0.0',
 'requests>=2.27.1,<3.0.0']

setup_kwargs = {
    'name': 'watchmen-ml-python-sdk',
    'version': '0.1.8',
    'description': '',
    'long_description': None,
    'author': 'luke0623',
    'author_email': 'luke0623@outlook.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.9,<4.0',
}


setup(**setup_kwargs)
